powered by
If stats is a list of functions, use them. If it is a single function, use it with the entire data as its argument to produce a list of statistical functions to use.
statTable(data, stats)
The dataframe to apply the statistic to
A list of named statistics to use
A dataframe of all statistics for all variables